==> ddup-0.0.1.tar.gz: ddup-0.0.1/setup.py <==
import os
import subprocess
import time
from setuptools import find_packages, setup
import tools


def readme():
    with open('README.md', encoding='utf-8') as f:
        content = f.read()
    return content


MAJOR = 0
MINOR = 0
PATCH = 1
SUFFIX = ''
if PATCH:
    SHORT_VERSION = '{}.{}.{}{}'.format(MAJOR, MINOR, PATCH, SUFFIX)
else:
    SHORT_VERSION = '{}.{}{}'.format(MAJOR, MINOR, SUFFIX)

version_file = 'dedup/version.py'


def get_git_hash():
    def _minimal_ext_cmd(cmd):
        # construct minimal environment
        env = {}
        for k in ['SYSTEMROOT', 'PATH', 'HOME']:
            v = os.environ.get(k)
            if v is not None:
                env[k] = v
        # LANGUAGE is used on win32
        env['LANGUAGE'] = 'C'
        env['LANG'] = 'C'
        env['LC_ALL'] = 'C'
        out = subprocess.Popen(
            cmd, stdout=subprocess.PIPE, env=env).communicate()[0]
        return out

    try:
        out = _minimal_ext_cmd(['git', 'rev-parse', 'HEAD'])
        sha = out.strip().decode('ascii')
    except OSError:
        sha = 'unknown'

    return sha


def get_hash():
    if os.path.exists('.git'):
        sha = get_git_hash()[:7]
    elif os.path.exists(version_file):
        try:
            from mmaction.version import __version__
            sha = __version__.split('+')[-1]
        except ImportError:
            raise ImportError('Unable to get git version')
    else:
        sha = 'unknown'

    return sha


# def write_version_py():
#     content = """# GENERATED VERSION FILE
#     # TIME: {}

#     __version__ = '{}'
#     short_version = '{}'
#     """
#     sha = get_hash()
#     VERSION = SHORT_VERSION + '+' + sha

#     with open(version_file, 'w') as f:
#         f.write(content.format(time.asctime(), VERSION, SHORT_VERSION))
def write_version_py():
    content = """# GENERATED VERSION FILE
# TIME: {}

__version__ = '{}'
short_version = '{}'
"""
    VERSION = SHORT_VERSION

    with open(version_file, 'w') as f:
        f.write(content.format(time.asctime(), VERSION, SHORT_VERSION))

def get_version():
    with open(version_file, 'r') as f:
        exec(compile(f.read(), version_file, 'exec'))
    return locals()['__version__']


def get_requirements(filename='requirements.txt'):
    here = os.path.dirname(os.path.realpath(__file__))
    with open(os.path.join(here, filename), 'r') as f:
        requires = [line.replace('\n', '') for line in f.readlines()]
    return requires


if __name__ == '__main__':
    write_version_py()
    setup(
        name='ddup',
        version=get_version(),
        description='',
        long_description=readme(),
        long_description_content_type='text/markdown',
        packages=find_packages(),
        package_dir={'dedup':'dedup'},
        package_data={'dedup': ['utils/black.png']},
        data_files=[
            ('dedup/utils', ['dedup/utils/black.png']),
        ],
        setup_requires=['pytest-runner'],
        tests_require=['pytest'],
        install_requires=get_requirements(),
        zip_safe=False,
        entry_points={
            'console_scripts': [
                'dedup = tools.dedupsdk:main'
            ]
        }
    )

==> ddup-0.0.2.tar.gz: ddup-0.0.2/setup.py <==
import os
import subprocess
import time
from setuptools import find_packages, setup
import tools


def readme():
    with open('README.md', encoding='utf-8') as f:
        content = f.read()
    return content


MAJOR = 0
MINOR = 0
PATCH = 2
SUFFIX = ''
if PATCH:
    SHORT_VERSION = '{}.{}.{}{}'.format(MAJOR, MINOR, PATCH, SUFFIX)
else:
    SHORT_VERSION = '{}.{}{}'.format(MAJOR, MINOR, SUFFIX)

version_file = 'dedup/version.py'


def get_git_hash():
    def _minimal_ext_cmd(cmd):
        # construct minimal environment
        env = {}
        for k in ['SYSTEMROOT', 'PATH', 'HOME']:
            v = os.environ.get(k)
            if v is not None:
                env[k] = v
        # LANGUAGE is used on win32
        env['LANGUAGE'] = 'C'
        env['LANG'] = 'C'
        env['LC_ALL'] = 'C'
        out = subprocess.Popen(
            cmd, stdout=subprocess.PIPE, env=env).communicate()[0]
        return out

    try:
        out = _minimal_ext_cmd(['git', 'rev-parse', 'HEAD'])
        sha = out.strip().decode('ascii')
    except OSError:
        sha = 'unknown'

    return sha


def get_hash():
    if os.path.exists('.git'):
        sha = get_git_hash()[:7]
    elif os.path.exists(version_file):
        try:
            from mmaction.version import __version__
            sha = __version__.split('+')[-1]
        except ImportError:
            raise ImportError('Unable to get git version')
    else:
        sha = 'unknown'

    return sha


# def write_version_py():
#     content = """# GENERATED VERSION FILE
#     # TIME: {}

#     __version__ = '{}'
#     short_version = '{}'
#     """
#     sha = get_hash()
#     VERSION = SHORT_VERSION + '+' + sha

#     with open(version_file, 'w') as f:
#         f.write(content.format(time.asctime(), VERSION, SHORT_VERSION))
def write_version_py():
    content = """# GENERATED VERSION FILE
# TIME: {}

__version__ = '{}'
short_version = '{}'
"""
    VERSION = SHORT_VERSION

    with open(version_file, 'w') as f:
        f.write(content.format(time.asctime(), VERSION, SHORT_VERSION))

def get_version():
    with open(version_file, 'r') as f:
        exec(compile(f.read(), version_file, 'exec'))
    return locals()['__version__']


def get_requirements(filename='requirements.txt'):
    here = os.path.dirname(os.path.realpath(__file__))
    with open(os.path.join(here, filename), 'r') as f:
        requires = [line.replace('\n', '') for line in f.readlines()]
    return requires


if __name__ == '__main__':
    write_version_py()
    setup(
        name='ddup',
        version=get_version(),
        description='',
        long_description=readme(),
        long_description_content_type='text/markdown',
        packages=find_packages(),
        package_dir={'dedup':'dedup'},
        package_data={'dedup': ['utils/black.png']},
        data_files=[
            ('dedup/utils', ['dedup/utils/black.png']),
        ],
        setup_requires=['pytest-runner'],
        tests_require=['pytest'],
        install_requires=get_requirements(),
        zip_safe=False,
        entry_points={
            'console_scripts': [
                'ddup = tools.dedupsdk:main'
            ]
        }
    )
